Module obj

Module obj 

Structs

Color
(R, G, B)
Config

Enums

ColorStorage

Functions

generate
generates OBJ bytes from activity map. NOTE: Colors are stored either in vertices normals or texture vertices.
generate_string
generates OBJ string from activity map. NOTE: Colors are stored either in vertices normals or texture vertices.